@@ -32,17 +32,18 @@ and file names:
 """
 
 
-import                      os
-import os.path           as op
-import itertools         as it
-import                      json
-import                      string
-import                      logging
-import                      tempfile
+import                  os
+import os.path   as     op
+import itertools as     it
+import                  json
+import                  string
+import                  logging
+import                  tempfile
+
+from pathlib import Path
+from typing  import Union
 
-import                      six
 import numpy             as np
-
 import nibabel           as nib
 import nibabel.fileslice as fileslice
 
@@ -56,6 +57,10 @@ import fsl.data.constants    as constants
 import fsl.data.imagewrapper as imagewrapper
 
 
+PathLike    = Union[str, Path]
+ImageSource = Union[PathLike, nib.Nifti1Image, np.ndarray, 'Image']
+
+
 log = logging.getLogger(__name__)
 
 
@@ -991,21 +996,22 @@ class Image(Nifti):
 
 
     def __init__(self,
-                 image,
-                 name=None,
-                 header=None,
-                 xform=None,
-                 loadData=True,
-                 calcRange=True,
-                 threaded=False,
-                 dataSource=None,
-                 loadMeta=False,
+                 image      : ImageSource,
+                 name       : str              = None,
+                 header     : nib.Nifti1Header = None,
+                 xform      : np.ndarray       = None,
+                 loadData   : bool             = True,
+                 calcRange  : bool             = True,
+                 threaded   : bool             = False,
+                 dataSource : PathLike         = None,
+                 loadMeta   : bool             = False,
                  **kwargs):
         """Create an ``Image`` object with the given image data or file name.
 
         :arg image:      A string containing the name of an image file to load,
-                         or a :mod:`numpy` array, or a :mod:`nibabel` image
-                         object, or an ``Image`` object.
+                         or a Path object pointing to an image file, or a
+                         :mod:`numpy` array, or a :mod:`nibabel` image object,
+                         or an ``Image`` object.
 
         :arg name:       A name for the image.
 
@@ -1083,7 +1089,7 @@ class Image(Nifti):
             header.set_qform(xform, code=qform)
 
         # The image parameter may be the name of an image file
-        if isinstance(image, six.string_types):
+        if isinstance(image, (str, Path)):
             image      = op.abspath(addExt(image))
             nibImage   = nib.load(image, **kwargs)
             dataSource = image
@@ -1133,12 +1139,12 @@ class Image(Nifti):
             nibImage = image
 
         # Figure out the name of this image, if
-        # it has not beenbeen explicitly passed in
+        # it has not been explicitly passed in
         if name is None:
 
             # If this image was loaded
             # from disk, use the file name.
-            if isinstance(image, six.string_types):
+            if isinstance(image, (str, Path)):
                 name = removeExt(op.basename(image))
 
             # Or the image was created from a numpy array
@@ -1206,7 +1212,8 @@ class Image(Nifti):
 
     def __del__(self):
         """Closes any open file handles, and clears some references. """
-        Nifti.__del__(self)
+        if Nifti is not None:
+            Nifti.__del__(self)
         self.__nibImage     = None
         self.__imageWrapper = None
 
