@@ -6,8 +6,6 @@
 #
 
 
-from __future__ import division
-
 import                 random
 import                 glob
 import os.path      as op
@@ -15,8 +13,6 @@ import itertools    as it
 import numpy        as np
 import numpy.linalg as npla
 
-import six
-
 import pytest
 
 import fsl.transform.affine  as affine
@@ -39,8 +35,7 @@ def readlines(filename):
         #
         # Pass it [bytes, bytes, ...], and it works
         # fine.
-        if six.PY3:
-            lines = [l.encode('ascii') for l in lines]
+        lines = [l.encode('ascii') for l in lines]
 
     return lines
 
@@ -395,7 +390,7 @@ def test_transform():
         mask = np.array([[1, 0, 0, 1],
                          [0, 1, 0, 1],
                          [0, 0, 1, 1],
-                         [0, 0, 0, 1]], dtype=np.bool)
+                         [0, 0, 0, 1]], dtype=bool)
 
         return np.all((xform != 0) == mask)
 
